/* **********************************************
     Begin jquery.cookie.js
********************************************** */

/**
 * Cookie plugin
 *
 * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */

/**
 * Create a cookie with the given name and value and other optional parameters.
 *
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Set the value of a cookie.
 * @example $.cookie('the_cookie', 'the_value', { expires: 7, path: '/', domain: 'jquery.com', secure: true });
 * @desc Create a cookie with all available options.
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Create a session cookie.
 * @example $.cookie('the_cookie', null);
 * @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
 *       used when the cookie was set.
 *
 * @param String name The name of the cookie.
 * @param String value The value of the cookie.
 * @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
 * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
 *                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
 *                             If set to null or omitted, the cookie will be a session cookie and will not be retained
 *                             when the the browser exits.
 * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
 * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
 * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
 *                        require a secure protocol (like HTTPS).
 * @type undefined
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */

/**
 * Get the value of a cookie with the given name.
 *
 * @example $.cookie('the_cookie');
 * @desc Get the value of a cookie.
 *
 * @param String name The name of the cookie.
 * @return The value of the cookie.
 * @type String
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */
 jQuery.cookie = function(name, value, options) {
  if (typeof value != 'undefined') { // name and value given, set cookie
      options = options || {};
      if (value === null) {
          value = '';
          options.expires = -1;
      }
      var expires = '';
      if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
          var date;
          if (typeof options.expires == 'number') {
              date = new Date();
              date.setTime(date.getTime() + (options.expires * 60 * 1000));
          } else {
              date = options.expires;
          }
          expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
      }
      // CAUTION: Needed to parenthesize options.path and options.domain
      // in the following expressions, otherwise they evaluate to undefined
      // in the packed version for some reason...
      var path = options.path ? '; path=' + (options.path) : '';
      var domain = options.domain ? '; domain=' + (options.domain) : '';
      var secure = options.secure ? '; secure' : '';
      document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
  } else { // only name given, get cookie
      var cookieValue = null;
      if (document.cookie && document.cookie != '') {
          var cookies = document.cookie.split(';');
          for (var i = 0; i < cookies.length; i++) {
              var cookie = jQuery.trim(cookies[i]);
              // Does this cookie string begin with the name we want?
              if (cookie.substring(0, name.length + 1) == (name + '=')) {
                  cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
                  break;
              }
          }
      }
      return cookieValue;
  }
};

/* **********************************************
   Begin jquery.apprise.js
********************************************** */

// Apprise 1.5 by Daniel Raftery
// http://thrivingkings.com/apprise
//
// Conversion to jQuery plugin by Adam Bezulski
// http://www.bezulski.com

(function ($) {
$.apprise = {
  defaults: {
    'confirm': false, 		// Shows OK and Cancel buttons
    'verify': false, 		// Shows Yes and No buttons
    'input': false, 		// Returns with user inputed text
    'animate': false, 		// Groovy animation (can true or number, default is 400)
    'txtOK': 'OK',			// Text for OK
    'txtCancel': 'Cancel',	// Text for Cancel
    'txtYes': 'Yes',		// Text for Yes
    'txtNo': 'No',			// Text for No
    'showFooter': false			// Copyright for GIT
  }
};
$.fn.extend({
  apprise: function (string, options, callback) {
    var args = $.fn.extend({}, $.apprise.defaults, options);

    if (args) {
      for (var index in args){ 
        if (typeof args[index] == "undefined") args[index] = defaults[index];
      }
    }

    var aHeight = $(document).height();
    var aWidth = $(document).width();
    $('body').append('<div class="appriseOverlay" id="aOverlay"></div>');
    $('.appriseOverlay').css('height', aHeight).css('width', aWidth).fadeIn(1);
    $('body').append('<div class="appriseOuter"></div>');
    $('.appriseOuter').append('<div class="appriseInner"></div>');
    $('.appriseInner').append(string);
    $('.appriseOuter').css("left", ($(window).width() - $('.appriseOuter').width()) / 2 + $(window).scrollLeft() + "px");

    if (args) {
      if (args['animate']) {
        var aniSpeed = args['animate'];
        if (isNaN(aniSpeed)) { aniSpeed = 1; }
        $('.appriseOuter').css('top', '-200px').show().animate({ top: "100px" }, aniSpeed);
      } else {
        $('.appriseOuter').css('top', '100px').fadeIn(1);
      }
    } else {
      $('.appriseOuter').css('top', '100px').fadeIn(1);
    }

    if (args) {
      if (args['input']) {
        $('.appriseInner').append('<div class="aInput"><input type="text" class="aTextbox" t="aTextbox" /></div>');
        $('.aTextbox').focus();
      }
    }

    $('.appriseInner').append('<div class="aButtons"></div>');
    if (args) {
      if (args['confirm'] || args['input']) {
        $('.aButtons').append('<button value="ok">' + args.txtOK + '</button>');
        $('.aButtons').append('<button value="cancel">' + args.txtCancel + '</button>');
      } else if (args['verify']) {
        $('.aButtons').append('<button value="ok">' + args.txtYes + '</button>');
        $('.aButtons').append('<button value="cancel">' + args.txtNo + '</button>');
      } else {
        $('.aButtons').append('<button value="ok">' + args.txtOK + '</button>');
      }
    } else { 
      $('.aButtons').append('<button value="ok">' + args.txtOK + '</button>');
    }

    if(args && args['showFooter'] === true) {
      //$('.appriseInner').append('<p class="copyright">&copy; 2017 CNL Strategic Captial Management, LLC. All Rights Reserved.</p>');
    }

    $(document).keypress(function (e) {
      if ($('.appriseOverlay').is(':visible')) {
        if (e.keyCode == 13) {
          $('.aButtons > button[value="ok"]').click();
        }
      }
    });

    var aText = false;
    $('.aTextbox').keyup(function ()
    { aText = $(this).val(); });

    $('.aButtons > button').click(function () {
      $('.appriseOverlay').remove();
      $('.appriseOuter').remove();
      if (callback) {
        var wButton = $(this).attr("value");
        if (wButton == 'ok') {
          if (args) {
            if (args['input'])
            { callback(aText); }
            else
            { callback(true); }
          }
          else
          { callback(true); }
        }
        else if (wButton == 'cancel')
        { callback(false); }
      }
    });
  }
});
})(jQuery);

// t: current time, b: begInnIng value, c: change In value, d: duration
eval(function(p,a,c,k,e,r){e=function(c){return(c<a?'':e(parseInt(c/a)))+((c=c%a)>35?String.fromCharCode(c+29):c.toString(36))};if(!''.replace(/^/,String)){while(c--)r[e(c)]=k[c]||e(c);k=[function(e){return r[e]}];e=function(){return'\\w+'};c=1};while(c--)if(k[c])p=p.replace(new RegExp('\\b'+e(c)+'\\b','g'),k[c]);return p}('h.i[\'1a\']=h.i[\'z\'];h.O(h.i,{y:\'D\',z:9(x,t,b,c,d){6 h.i[h.i.y](x,t,b,c,d)},17:9(x,t,b,c,d){6 c*(t/=d)*t+b},D:9(x,t,b,c,d){6-c*(t/=d)*(t-2)+b},13:9(x,t,b,c,d){e((t/=d/2)<1)6 c/2*t*t+b;6-c/2*((--t)*(t-2)-1)+b},X:9(x,t,b,c,d){6 c*(t/=d)*t*t+b},U:9(x,t,b,c,d){6 c*((t=t/d-1)*t*t+1)+b},R:9(x,t,b,c,d){e((t/=d/2)<1)6 c/2*t*t*t+b;6 c/2*((t-=2)*t*t+2)+b},N:9(x,t,b,c,d){6 c*(t/=d)*t*t*t+b},M:9(x,t,b,c,d){6-c*((t=t/d-1)*t*t*t-1)+b},L:9(x,t,b,c,d){e((t/=d/2)<1)6 c/2*t*t*t*t+b;6-c/2*((t-=2)*t*t*t-2)+b},K:9(x,t,b,c,d){6 c*(t/=d)*t*t*t*t+b},J:9(x,t,b,c,d){6 c*((t=t/d-1)*t*t*t*t+1)+b},I:9(x,t,b,c,d){e((t/=d/2)<1)6 c/2*t*t*t*t*t+b;6 c/2*((t-=2)*t*t*t*t+2)+b},G:9(x,t,b,c,d){6-c*8.C(t/d*(8.g/2))+c+b},15:9(x,t,b,c,d){6 c*8.n(t/d*(8.g/2))+b},12:9(x,t,b,c,d){6-c/2*(8.C(8.g*t/d)-1)+b},Z:9(x,t,b,c,d){6(t==0)?b:c*8.j(2,10*(t/d-1))+b},Y:9(x,t,b,c,d){6(t==d)?b+c:c*(-8.j(2,-10*t/d)+1)+b},W:9(x,t,b,c,d){e(t==0)6 b;e(t==d)6 b+c;e((t/=d/2)<1)6 c/2*8.j(2,10*(t-1))+b;6 c/2*(-8.j(2,-10*--t)+2)+b},V:9(x,t,b,c,d){6-c*(8.o(1-(t/=d)*t)-1)+b},S:9(x,t,b,c,d){6 c*8.o(1-(t=t/d-1)*t)+b},Q:9(x,t,b,c,d){e((t/=d/2)<1)6-c/2*(8.o(1-t*t)-1)+b;6 c/2*(8.o(1-(t-=2)*t)+1)+b},P:9(x,t,b,c,d){f s=1.l;f p=0;f a=c;e(t==0)6 b;e((t/=d)==1)6 b+c;e(!p)p=d*.3;e(a<8.w(c)){a=c;f s=p/4}m f s=p/(2*8.g)*8.r(c/a);6-(a*8.j(2,10*(t-=1))*8.n((t*d-s)*(2*8.g)/p))+b},H:9(x,t,b,c,d){f s=1.l;f p=0;f a=c;e(t==0)6 b;e((t/=d)==1)6 b+c;e(!p)p=d*.3;e(a<8.w(c)){a=c;f s=p/4}m f s=p/(2*8.g)*8.r(c/a);6 a*8.j(2,-10*t)*8.n((t*d-s)*(2*8.g)/p)+c+b},T:9(x,t,b,c,d){f s=1.l;f p=0;f a=c;e(t==0)6 b;e((t/=d/2)==2)6 b+c;e(!p)p=d*(.3*1.5);e(a<8.w(c)){a=c;f s=p/4}m f s=p/(2*8.g)*8.r(c/a);e(t<1)6-.5*(a*8.j(2,10*(t-=1))*8.n((t*d-s)*(2*8.g)/p))+b;6 a*8.j(2,-10*(t-=1))*8.n((t*d-s)*(2*8.g)/p)*.5+c+b},F:9(x,t,b,c,d,s){e(s==u)s=1.l;6 c*(t/=d)*t*((s+1)*t-s)+b},E:9(x,t,b,c,d,s){e(s==u)s=1.l;6 c*((t=t/d-1)*t*((s+1)*t+s)+1)+b},16:9(x,t,b,c,d,s){e(s==u)s=1.l;e((t/=d/2)<1)6 c/2*(t*t*(((s*=(1.B))+1)*t-s))+b;6 c/2*((t-=2)*t*(((s*=(1.B))+1)*t+s)+2)+b},A:9(x,t,b,c,d){6 c-h.i.v(x,d-t,0,c,d)+b},v:9(x,t,b,c,d){e((t/=d)<(1/2.k)){6 c*(7.q*t*t)+b}m e(t<(2/2.k)){6 c*(7.q*(t-=(1.5/2.k))*t+.k)+b}m e(t<(2.5/2.k)){6 c*(7.q*(t-=(2.14/2.k))*t+.11)+b}m{6 c*(7.q*(t-=(2.18/2.k))*t+.19)+b}},1b:9(x,t,b,c,d){e(t<d/2)6 h.i.A(x,t*2,0,c,d)*.5+b;6 h.i.v(x,t*2-d,0,c,d)*.5+c*.5+b}});',62,74,'||||||return||Math|function|||||if|var|PI|jQuery|easing|pow|75|70158|else|sin|sqrt||5625|asin|||undefined|easeOutBounce|abs||def|swing|easeInBounce|525|cos|easeOutQuad|easeOutBack|easeInBack|easeInSine|easeOutElastic|easeInOutQuint|easeOutQuint|easeInQuint|easeInOutQuart|easeOutQuart|easeInQuart|extend|easeInElastic|easeInOutCirc|easeInOutCubic|easeOutCirc|easeInOutElastic|easeOutCubic|easeInCirc|easeInOutExpo|easeInCubic|easeOutExpo|easeInExpo||9375|easeInOutSine|easeInOutQuad|25|easeOutSine|easeInOutBack|easeInQuad|625|984375|jswing|easeInOutBounce'.split('|'),0,{}))

/*
*
* TERMS OF USE - EASING EQUATIONS
* 
* Open source under the BSD License. 
* 
* Copyright ? 2001 Robert Penner
* All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without modification, 
* are permitted provided that the following conditions are met:
* 
* Redistributions of source code must retain the above copyright notice, this list of 
* conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice, this list 
* of conditions and the following disclaimer in the documentation and/or other materials 
* provided with the distribution.
* 
* Neither the name of the author nor the names of contributors may be used to endorse 
* or promote products derived from this software without specific prior written permission.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
*  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
*  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
*  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
*  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
* OF THE POSSIBILITY OF SUCH DAMAGE. 
*
*/


/* **********************************************
   Begin jquery.fancybox.js
********************************************** */

/*
* FancyBox - jQuery Plugin
* Simple and fancy lightbox alternative
*
* Examples and documentation at: http://fancybox.net
* 
* Copyright (c) 2008 - 2010 Janis Skarnelis
* That said, it is hardly a one-person project. Many people have submitted bugs, code, and offered their advice freely. Their support is greatly appreciated.
* 
* Version: 1.3.4 (11/11/2010)
* Requires: jQuery v1.3+
*
* Dual licensed under the MIT and GPL licenses:
*   http://www.opensource.org/licenses/mit-license.php
*   http://www.gnu.org/licenses/gpl.html
*/

;(function(b){var m,t,u,f,D,j,E,n,z,A,q=0,e={},o=[],p=0,d={},l=[],G=null,v=new Image,J=/\.(jpg|gif|png|bmp|jpeg)(.*)?$/i,W=/[^\.]\.(swf)\s*$/i,K,L=1,y=0,s="",r,i,h=false,B=b.extend(b("<div/>")[0],{prop:0}),M=b.browser.msie&&b.browser.version<7&&!window.XMLHttpRequest,N=function(){t.hide();v.onerror=v.onload=null;G&&G.abort();m.empty()},O=function(){if(false===e.onError(o,q,e)){t.hide();h=false}else{e.titleShow=false;e.width="auto";e.height="auto";m.html('<p id="fancybox-error">The requested content cannot be loaded.<br />Please try again later.</p>');
F()}},I=function(){var a=o[q],c,g,k,C,P,w;N();e=b.extend({},b.fn.fancybox.defaults,typeof b(a).data("fancybox")=="undefined"?e:b(a).data("fancybox"));w=e.onStart(o,q,e);if(w===false)h=false;else{if(typeof w=="object")e=b.extend(e,w);k=e.title||(a.nodeName?b(a).attr("title"):a.title)||"";if(a.nodeName&&!e.orig)e.orig=b(a).children("img:first").length?b(a).children("img:first"):b(a);if(k===""&&e.orig&&e.titleFromAlt)k=e.orig.attr("alt");c=e.href||(a.nodeName?b(a).attr("href"):a.href)||null;if(/^(?:javascript)/i.test(c)||
c=="#")c=null;if(e.type){g=e.type;if(!c)c=e.content}else if(e.content)g="html";else if(c)g=c.match(J)?"image":c.match(W)?"swf":b(a).hasClass("iframe")?"iframe":c.indexOf("#")===0?"inline":"ajax";if(g){if(g=="inline"){a=c.substr(c.indexOf("#"));g=b(a).length>0?"inline":"ajax"}e.type=g;e.href=c;e.title=k;if(e.autoDimensions)if(e.type=="html"||e.type=="inline"||e.type=="ajax"){e.width="auto";e.height="auto"}else e.autoDimensions=false;if(e.modal){e.overlayShow=true;e.hideOnOverlayClick=false;e.hideOnContentClick=
false;e.enableEscapeButton=false;e.showCloseButton=false}e.padding=parseInt(e.padding,10);e.margin=parseInt(e.margin,10);m.css("padding",e.padding+e.margin);b(".fancybox-inline-tmp").unbind("fancybox-cancel").bind("fancybox-change",function(){b(this).replaceWith(j.children())});switch(g){case "html":m.html(e.content);F();break;case "inline":if(b(a).parent().is("#fancybox-content")===true){h=false;break}b('<div class="fancybox-inline-tmp" />').hide().insertBefore(b(a)).bind("fancybox-cleanup",function(){b(this).replaceWith(j.children())}).bind("fancybox-cancel",
function(){b(this).replaceWith(m.children())});b(a).appendTo(m);F();break;case "image":h=false;b.fancybox.showActivity();v=new Image;v.onerror=function(){O()};v.onload=function(){h=true;v.onerror=v.onload=null;e.width=v.width;e.height=v.height;b("<img />").attr({id:"fancybox-img",src:v.src,alt:e.title}).appendTo(m);Q()};v.src=c;break;case "swf":e.scrolling="no";C='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" width="'+e.width+'" height="'+e.height+'"><param name="movie" value="'+c+
'"></param>';P="";b.each(e.swf,function(x,H){C+='<param name="'+x+'" value="'+H+'"></param>';P+=" "+x+'="'+H+'"'});C+='<embed src="'+c+'" type="application/x-shockwave-flash" width="'+e.width+'" height="'+e.height+'"'+P+"></embed></object>";m.html(C);F();break;case "ajax":h=false;b.fancybox.showActivity();e.ajax.win=e.ajax.success;G=b.ajax(b.extend({},e.ajax,{url:c,data:e.ajax.data||{},error:function(x){x.status>0&&O()},success:function(x,H,R){if((typeof R=="object"?R:G).status==200){if(typeof e.ajax.win==
"function"){w=e.ajax.win(c,x,H,R);if(w===false){t.hide();return}else if(typeof w=="string"||typeof w=="object")x=w}m.html(x);F()}}}));break;case "iframe":Q()}}else O()}},F=function(){var a=e.width,c=e.height;a=a.toString().indexOf("%")>-1?parseInt((b(window).width()-e.margin*2)*parseFloat(a)/100,10)+"px":a=="auto"?"auto":a+"px";c=c.toString().indexOf("%")>-1?parseInt((b(window).height()-e.margin*2)*parseFloat(c)/100,10)+"px":c=="auto"?"auto":c+"px";m.wrapInner('<div style="width:'+a+";height:"+c+
";overflow: "+(e.scrolling=="auto"?"auto":e.scrolling=="yes"?"scroll":"hidden")+';position:relative;"></div>');e.width=m.width();e.height=m.height();Q()},Q=function(){var a,c;t.hide();if(f.is(":visible")&&false===d.onCleanup(l,p,d)){b.event.trigger("fancybox-cancel");h=false}else{h=true;b(j.add(u)).unbind();b(window).unbind("resize.fb scroll.fb");b(document).unbind("keydown.fb");f.is(":visible")&&d.titlePosition!=="outside"&&f.css("height",f.height());l=o;p=q;d=e;if(d.overlayShow){u.css({"background-color":d.overlayColor,
opacity:d.overlayOpacity,cursor:d.hideOnOverlayClick?"pointer":"auto",height:b(document).height()});if(!u.is(":visible")){M&&b("select:not(#fancybox-tmp select)").filter(function(){return this.style.visibility!=="hidden"}).css({visibility:"hidden"}).one("fancybox-cleanup",function(){this.style.visibility="inherit"});u.show()}}else u.hide();i=X();s=d.title||"";y=0;n.empty().removeAttr("style").removeClass();if(d.titleShow!==false){if(b.isFunction(d.titleFormat))a=d.titleFormat(s,l,p,d);else a=s&&s.length?
d.titlePosition=="float"?'<table id="fancybox-title-float-wrap" cellpadding="0" cellspacing="0"><tr><td id="fancybox-title-float-left"></td><td id="fancybox-title-float-main">'+s+'</td><td id="fancybox-title-float-right"></td></tr></table>':'<div id="fancybox-title-'+d.titlePosition+'">'+s+"</div>":false;s=a;if(!(!s||s==="")){n.addClass("fancybox-title-"+d.titlePosition).html(s).appendTo("body").show();switch(d.titlePosition){case "inside":n.css({width:i.width-d.padding*2,marginLeft:d.padding,marginRight:d.padding});
y=n.outerHeight(true);n.appendTo(D);i.height+=y;break;case "over":n.css({marginLeft:d.padding,width:i.width-d.padding*2,bottom:d.padding}).appendTo(D);break;case "float":n.css("left",parseInt((n.width()-i.width-40)/2,10)*-1).appendTo(f);break;default:n.css({width:i.width-d.padding*2,paddingLeft:d.padding,paddingRight:d.padding}).appendTo(f)}}}n.hide();if(f.is(":visible")){b(E.add(z).add(A)).hide();a=f.position();r={top:a.top,left:a.left,width:f.width(),height:f.height()};c=r.width==i.width&&r.height==
i.height;j.fadeTo(d.changeFade,0.3,function(){var g=function(){j.html(m.contents()).fadeTo(d.changeFade,1,S)};b.event.trigger("fancybox-change");j.empty().removeAttr("filter").css({"border-width":d.padding,width:i.width-d.padding*2,height:e.autoDimensions?"auto":i.height-y-d.padding*2});if(c)g();else{B.prop=0;b(B).animate({prop:1},{duration:d.changeSpeed,easing:d.easingChange,step:T,complete:g})}})}else{f.removeAttr("style");j.css("border-width",d.padding);if(d.transitionIn=="elastic"){r=V();j.html(m.contents());
f.show();if(d.opacity)i.opacity=0;B.prop=0;b(B).animate({prop:1},{duration:d.speedIn,easing:d.easingIn,step:T,complete:S})}else{d.titlePosition=="inside"&&y>0&&n.show();j.css({width:i.width-d.padding*2,height:e.autoDimensions?"auto":i.height-y-d.padding*2}).html(m.contents());f.css(i).fadeIn(d.transitionIn=="none"?0:d.speedIn,S)}}}},Y=function(){if(d.enableEscapeButton||d.enableKeyboardNav)b(document).bind("keydown.fb",function(a){if(a.keyCode==27&&d.enableEscapeButton){a.preventDefault();b.fancybox.close()}else if((a.keyCode==
37||a.keyCode==39)&&d.enableKeyboardNav&&a.target.tagName!=="INPUT"&&a.target.tagName!=="TEXTAREA"&&a.target.tagName!=="SELECT"){a.preventDefault();b.fancybox[a.keyCode==37?"prev":"next"]()}});if(d.showNavArrows){if(d.cyclic&&l.length>1||p!==0)z.show();if(d.cyclic&&l.length>1||p!=l.length-1)A.show()}else{z.hide();A.hide()}},S=function(){if(!b.support.opacity){j.get(0).style.removeAttribute("filter");f.get(0).style.removeAttribute("filter")}e.autoDimensions&&j.css("height","auto");f.css("height","auto");
s&&s.length&&n.show();d.showCloseButton&&E.show();Y();d.hideOnContentClick&&j.bind("click",b.fancybox.close);d.hideOnOverlayClick&&u.bind("click",b.fancybox.close);b(window).bind("resize.fb",b.fancybox.resize);d.centerOnScroll&&b(window).bind("scroll.fb",b.fancybox.center);if(d.type=="iframe")b('<iframe id="fancybox-frame" name="fancybox-frame'+(new Date).getTime()+'" frameborder="0" hspace="0" '+(b.browser.msie?'allowtransparency="true""':"")+' scrolling="'+e.scrolling+'" src="'+d.href+'"></iframe>').appendTo(j);
f.show();h=false;b.fancybox.center();d.onComplete(l,p,d);var a,c;if(l.length-1>p){a=l[p+1].href;if(typeof a!=="undefined"&&a.match(J)){c=new Image;c.src=a}}if(p>0){a=l[p-1].href;if(typeof a!=="undefined"&&a.match(J)){c=new Image;c.src=a}}},T=function(a){var c={width:parseInt(r.width+(i.width-r.width)*a,10),height:parseInt(r.height+(i.height-r.height)*a,10),top:parseInt(r.top+(i.top-r.top)*a,10),left:parseInt(r.left+(i.left-r.left)*a,10)};if(typeof i.opacity!=="undefined")c.opacity=a<0.5?0.5:a;f.css(c);
j.css({width:c.width-d.padding*2,height:c.height-y*a-d.padding*2})},U=function(){return[b(window).width()-d.margin*2,b(window).height()-d.margin*2,b(document).scrollLeft()+d.margin,b(document).scrollTop()+d.margin]},X=function(){var a=U(),c={},g=d.autoScale,k=d.padding*2;c.width=d.width.toString().indexOf("%")>-1?parseInt(a[0]*parseFloat(d.width)/100,10):d.width+k;c.height=d.height.toString().indexOf("%")>-1?parseInt(a[1]*parseFloat(d.height)/100,10):d.height+k;if(g&&(c.width>a[0]||c.height>a[1]))if(e.type==
"image"||e.type=="swf"){g=d.width/d.height;if(c.width>a[0]){c.width=a[0];c.height=parseInt((c.width-k)/g+k,10)}if(c.height>a[1]){c.height=a[1];c.width=parseInt((c.height-k)*g+k,10)}}else{c.width=Math.min(c.width,a[0]);c.height=Math.min(c.height,a[1])}c.top=parseInt(Math.max(a[3]-20,a[3]+(a[1]-c.height-40)*0.5),10);c.left=parseInt(Math.max(a[2]-20,a[2]+(a[0]-c.width-40)*0.5),10);return c},V=function(){var a=e.orig?b(e.orig):false,c={};if(a&&a.length){c=a.offset();c.top+=parseInt(a.css("paddingTop"),
10)||0;c.left+=parseInt(a.css("paddingLeft"),10)||0;c.top+=parseInt(a.css("border-top-width"),10)||0;c.left+=parseInt(a.css("border-left-width"),10)||0;c.width=a.width();c.height=a.height();c={width:c.width+d.padding*2,height:c.height+d.padding*2,top:c.top-d.padding-20,left:c.left-d.padding-20}}else{a=U();c={width:d.padding*2,height:d.padding*2,top:parseInt(a[3]+a[1]*0.5,10),left:parseInt(a[2]+a[0]*0.5,10)}}return c},Z=function(){if(t.is(":visible")){b("div",t).css("top",L*-40+"px");L=(L+1)%12}else clearInterval(K)};
b.fn.fancybox=function(a){if(!b(this).length)return this;b(this).data("fancybox",b.extend({},a,b.metadata?b(this).metadata():{})).unbind("click.fb").bind("click.fb",function(c){c.preventDefault();if(!h){h=true;b(this).blur();o=[];q=0;c=b(this).attr("rel")||"";if(!c||c==""||c==="nofollow")o.push(this);else{o=b("a[rel="+c+"], area[rel="+c+"]");q=o.index(this)}I()}});return this};b.fancybox=function(a,c){var g;if(!h){h=true;g=typeof c!=="undefined"?c:{};o=[];q=parseInt(g.index,10)||0;if(b.isArray(a)){for(var k=
0,C=a.length;k<C;k++)if(typeof a[k]=="object")b(a[k]).data("fancybox",b.extend({},g,a[k]));else a[k]=b({}).data("fancybox",b.extend({content:a[k]},g));o=jQuery.merge(o,a)}else{if(typeof a=="object")b(a).data("fancybox",b.extend({},g,a));else a=b({}).data("fancybox",b.extend({content:a},g));o.push(a)}if(q>o.length||q<0)q=0;I()}};b.fancybox.showActivity=function(){clearInterval(K);t.show();K=setInterval(Z,66)};b.fancybox.hideActivity=function(){t.hide()};b.fancybox.next=function(){return b.fancybox.pos(p+
1)};b.fancybox.prev=function(){return b.fancybox.pos(p-1)};b.fancybox.pos=function(a){if(!h){a=parseInt(a);o=l;if(a>-1&&a<l.length){q=a;I()}else if(d.cyclic&&l.length>1){q=a>=l.length?0:l.length-1;I()}}};b.fancybox.cancel=function(){if(!h){h=true;b.event.trigger("fancybox-cancel");N();e.onCancel(o,q,e);h=false}};b.fancybox.close=function(){function a(){u.fadeOut("fast");n.empty().hide();f.hide();b.event.trigger("fancybox-cleanup");j.empty();d.onClosed(l,p,d);l=e=[];p=q=0;d=e={};h=false}if(!(h||f.is(":hidden"))){h=
true;if(d&&false===d.onCleanup(l,p,d))h=false;else{N();b(E.add(z).add(A)).hide();b(j.add(u)).unbind();b(window).unbind("resize.fb scroll.fb");b(document).unbind("keydown.fb");j.find("iframe").attr("src",M&&/^https/i.test(window.location.href||"")?"javascript:void(false)":"about:blank");d.titlePosition!=="inside"&&n.empty();f.stop();if(d.transitionOut=="elastic"){r=V();var c=f.position();i={top:c.top,left:c.left,width:f.width(),height:f.height()};if(d.opacity)i.opacity=1;n.empty().hide();B.prop=1;
b(B).animate({prop:0},{duration:d.speedOut,easing:d.easingOut,step:T,complete:a})}else f.fadeOut(d.transitionOut=="none"?0:d.speedOut,a)}}};b.fancybox.resize=function(){u.is(":visible")&&u.css("height",b(document).height());b.fancybox.center(true)};b.fancybox.center=function(a){var c,g;if(!h){g=a===true?1:0;c=U();!g&&(f.width()>c[0]||f.height()>c[1])||f.stop().animate({top:parseInt(Math.max(c[3]-20,c[3]+(c[1]-j.height()-40)*0.5-d.padding)),left:parseInt(Math.max(c[2]-20,c[2]+(c[0]-j.width()-40)*0.5-
d.padding))},typeof a=="number"?a:200)}};b.fancybox.init=function(){if(!b("#fancybox-wrap").length){b("body").append(m=b('<div id="fancybox-tmp"></div>'),t=b('<div id="fancybox-loading"><div></div></div>'),u=b('<div id="fancybox-overlay"></div>'),f=b('<div id="fancybox-wrap"></div>'));D=b('<div id="fancybox-outer"></div>').append('<div class="fancybox-bg" id="fancybox-bg-n"></div><div class="fancybox-bg" id="fancybox-bg-ne"></div><div class="fancybox-bg" id="fancybox-bg-e"></div><div class="fancybox-bg" id="fancybox-bg-se"></div><div class="fancybox-bg" id="fancybox-bg-s"></div><div class="fancybox-bg" id="fancybox-bg-sw"></div><div class="fancybox-bg" id="fancybox-bg-w"></div><div class="fancybox-bg" id="fancybox-bg-nw"></div>').appendTo(f);
D.append(j=b('<div id="fancybox-content"></div>'),E=b('<a id="fancybox-close"></a>'),n=b('<div id="fancybox-title"></div>'),z=b('<a href="javascript:;" id="fancybox-left"><span class="fancy-ico" id="fancybox-left-ico"></span></a>'),A=b('<a href="javascript:;" id="fancybox-right"><span class="fancy-ico" id="fancybox-right-ico"></span></a>'));E.click(b.fancybox.close);t.click(b.fancybox.cancel);z.click(function(a){a.preventDefault();b.fancybox.prev()});A.click(function(a){a.preventDefault();b.fancybox.next()});
b.fn.mousewheel&&f.bind("mousewheel.fb",function(a,c){if(h)a.preventDefault();else if(b(a.target).get(0).clientHeight==0||b(a.target).get(0).scrollHeight===b(a.target).get(0).clientHeight){a.preventDefault();b.fancybox[c>0?"prev":"next"]()}});b.support.opacity||f.addClass("fancybox-ie");if(M){t.addClass("fancybox-ie6");f.addClass("fancybox-ie6");b('<iframe id="fancybox-hide-sel-frame" src="'+(/^https/i.test(window.location.href||"")?"javascript:void(false)":"about:blank")+'" scrolling="no" border="0" frameborder="0" tabindex="-1"></iframe>').prependTo(D)}}};
b.fn.fancybox.defaults={padding:10,margin:40,opacity:false,modal:false,cyclic:false,scrolling:"auto",width:560,height:340,autoScale:true,autoDimensions:true,centerOnScroll:false,ajax:{},swf:{wmode:"transparent"},hideOnOverlayClick:true,hideOnContentClick:false,overlayShow:true,overlayOpacity:0.7,overlayColor:"#777",titleShow:true,titlePosition:"float",titleFormat:null,titleFromAlt:false,transitionIn:"fade",transitionOut:"fade",speedIn:300,speedOut:300,changeSpeed:300,changeFade:"fast",easingIn:"swing",
easingOut:"swing",showCloseButton:true,showNavArrows:true,enableEscapeButton:true,enableKeyboardNav:true,onStart:function(){},onCancel:function(){},onComplete:function(){},onCleanup:function(){},onClosed:function(){},onError:function(){}};b(document).ready(function(){b.fancybox.init()})})(jQuery);

/* **********************************************
   Begin jquery.swipe.js
********************************************** */

/*
* jSwipe - jQuery Plugin
* http://plugins.jquery.com/project/swipe
* http://www.ryanscherf.com/demos/swipe/
*
* Copyright (c) 2009 Ryan Scherf (www.ryanscherf.com)
* Licensed under the MIT license
*
* $Date: 2009-07-14 (Tue, 14 Jul 2009) $
* $version: 0.1.2
* 
* This jQuery plugin will only run on devices running Mobile Safari
* on iPhone or iPod Touch devices running iPhone OS 2.0 or later. 
* http://developer.apple.com/iphone/library/documentation/AppleApplications/Reference/SafariWebContent/HandlingEvents/HandlingEvents.html#//apple_ref/doc/uid/TP40006511-SW5
*/
(function($) {
$.fn.swipe = function(options) {
  
  // Default thresholds & swipe functions
  var defaults = {
    threshold: {
      x: 50,
      y: 200
    },
    swipeLeft: function() { alert('swiped left') },
    swipeRight: function() { alert('swiped right') }
  };
  
  var options = $.extend(defaults, options);
  
  if (!this) return false;
  
  return this.each(function() {
    
    var me = $(this)
    
    // Private variables for each element
    var originalCoord = { x: 0, y: 0 }
    var finalCoord = { x: 0, y: 0 }
    
    // Screen touched, store the original coordinate
    function touchStart(event) {
      //console.log('Starting swipe gesture...')
      originalCoord.x = event.targetTouches[0].pageX
      originalCoord.y = event.targetTouches[0].pageY
    }
    
    // Store coordinates as finger is swiping
    function touchMove(event) {
      //event.preventDefault();
      finalCoord.x = event.targetTouches[0].pageX // Updated X,Y coordinates
      finalCoord.y = event.targetTouches[0].pageY
      var change = originalCoord.x - finalCoord.x;
      if(change > 10 || change < -10) {
        event.preventDefault();
      }
    }
    
    // Done Swiping
    // Swipe should only be on X axis, ignore if swipe on Y axis
    // Calculate if the swipe was left or right
    function touchEnd(event) {
      //console.log('Ending swipe gesture...')
      var changeY = originalCoord.y - finalCoord.y
      if(changeY < defaults.threshold.y && changeY > (defaults.threshold.y*-1)) {
        changeX = originalCoord.x - finalCoord.x
        
        if(changeX > defaults.threshold.x) {
          defaults.swipeLeft()
        }
        if(changeX < (defaults.threshold.x*-1)) {
          defaults.swipeRight()
        }
      }
    }
    
    // Swipe was started
    function touchStart(event) {
      //console.log('Starting swipe gesture...')
      originalCoord.x = event.targetTouches[0].pageX
      originalCoord.y = event.targetTouches[0].pageY

      finalCoord.x = originalCoord.x
      finalCoord.y = originalCoord.y
    }
    
    // Swipe was canceled
    function touchCancel(event) { 
      //console.log('Canceling swipe gesture...')
    }
    
    // Add gestures to all swipable areas
    this.addEventListener("touchstart", touchStart, false);
    this.addEventListener("touchmove", touchMove, false);
    this.addEventListener("touchend", touchEnd, false);
    this.addEventListener("touchcancel", touchCancel, false);
      
  });
};
})(jQuery);


/* **********************************************
   Begin application.js
********************************************** */

var Modernizr = Modernizr || {};
var console = console || {};
//var alert = alert || {};
var confirm = confirm || {};

var CURRWIDTH, PREVWIDTH, SPEC, setSpec;

//Home Slider
var slider = (function() {
var t = {};
t.container = null;
t.current = 0;
t.mobile_ul = null;
t.timer = null;
t.views = {};
t.goTo = function(index) {
  clearTimeout(t.timer);
  t.setupTimer();
  var height = 177;
  if(SPEC === 'small') {
    height = 170;
  }
  var top = height * index;
  $('#slider').animate({
    top: '-'+top
  }, 1200, function() {});
};
t.highlightLink = function(index) {
  var nav_item = t.views.links.eq(index);
  t.views.links.removeClass('active');
  nav_item.addClass('active');
  
  var mobile_nav_item = t.mobile_ul.children('li').eq(index);
  mobile_nav_item.siblings('li').removeClass('active');
  mobile_nav_item.addClass('active');
};
t.mobileNav = function() {
  //Make a mobile nav with js to keep our main events clean
  t.mobile_ul = $('<ul id="slide_nav_mobile" />');
  for(var i = 0; i <= (t.views.links.length-1); i++) {
    t.mobile_ul.append('<li>'+i+'</li>');
  }
  $('li:first-child', t.mobile_ul).addClass('active');
  $('#slider_wrapper').after(t.mobile_ul);
  $('li', t.mobile_ul).click(function(e) {
    e.preventDefault();
    var index = $(this).index();
    t.current = index;
    t.highlightLink(index);
    t.goTo(index);
  });
};
t.realign = function() {
  var height = 177;
  if(SPEC === 'small') {
    height = 190;
  }
  var top = height * t.current;
  $('#slider').css('top', '-'+top);
};
t.setupEvents = function() {
  $('a', t.views.links).click(function(e) {
    e.preventDefault();
    var dad = $(this).parents('li');
    var index = dad.index();
    if(index !== t.current) {
      t.current = index;
      t.highlightLink(index);
      t.goTo(index);
    }
  });
};
t.setupTimer = function() {
  t.timer = setTimeout(function() {
    t.current += 1;
    if((t.current + 1) > t.views.items.length) {
      t.current = 0;
    }
    t.highlightLink(t.current);
    t.goTo(t.current);
  }, 4000);
};
t.setupViews = function() {
  t.views.items = $('#slider li');
  t.views.links = $('#slide_nav li');
  $('a', t.views.links).prepend('<b class="arrow" />');
  t.container.after('<div class="slider_shadow" />');
};
t.init = function() {
  t.container = $('#home_slider');
  if(t.container.length > 0) {
    t.setupViews();
    t.setupEvents();
    t.setupTimer();
    t.mobileNav();
  }
};
return t;
})();

//External and pdf links
var links = (function() {
var t = {};
t.appriseExternal = function(link) {
  var message = '<p>You\'ve requested a website created and maintained by an entity'+
                '<br />other than CNL Strategic Capital'+
                '<br /><br />Click "OK" to proceed to the page you have requested.'+
                '<br />Click "Cancel" to return to the previous page.</p>';
  link.apprise(message, {'confirm': true, 'showFooter': true}, function(r) {
    if(r === true) {
      window.open(link.attr('href'));
    }
  });
};
t.mobileExternal = function(link) {
  //var answer = confirm("You've requested a website created and maintained by an entity other than CNL Strategic Capital\n\nClick \"OK\" to proceed to the page you have requested. Click \"Cancel\" to return to the previous page.\n\nCopyright (c) 2017 CNL Strategic Capital Management, LLC. All Rights Reserved.");
      var answer = confirm("You've requested a website created and maintained by an entity other than CNL Strategic Capital\n\nClick \"OK\" to proceed to the page you have requested. Click \"Cancel\" to return to the previous page.");
  if(answer) {
    window.open(link.attr('href'));
  }
};
t.overviewDesktop = function(link) {
  var message = '<p>Not for use in OH'+
                '<br /><br />Click "OK" to proceed to the document you have requested.'+
                '<br />Click "Cancel" to return to the previous page.</p>';
  link.apprise(message, {'confirm': true, 'showFooter': true}, function(r) {
    if(r === true) {
      window.open(link.attr('href'));
    }
  });
};
t.overviewMobile = function(link) {
  //var answer = confirm("You've requested a website created and maintained by an entity other than CNL Strategic Capital\n\nClick \"OK\" to proceed to the page you have requested. Click \"Cancel\" to return to the previous page.\n\nCopyright (c) 2017 CNL Strategic Capital Management, LLC. All Rights Reserved.");
      var answer = confirm("Not for use in OH\n\nClick \"OK\" to proceed to the document you have requested. Click \"Cancel\" to return to the previous page.");
  if(answer) {
    window.open(link.attr('href'));
  }
};	
t.setupEvents = function() {
  $('a[rel=external]').click(function(e) {
    console.log('Large');
    e.preventDefault();
    var link = $(this);
    if(SPEC === 'large') {
      t.appriseExternal(link);
    } else {
      t.mobileExternal(link);
    }
  });
  $('a[rel=overview]').click(function(e) {
    console.log('Large');
    e.preventDefault();
    var link = $(this);
    if(SPEC === 'large') {
      t.overviewDesktop(link);
    } else {
      t.overviewMobile(link);
    }
  });
};
t.init = function() {
  $('#container a').each(function() {
    var a, pdf, email;
    a = new RegExp('/' + window.location.host + '/');
    email = new RegExp('mailto');
    pdf = new RegExp('.pdf');
    if(!email.test(this.href) && (!a.test(this.href) || pdf.test(this.href))) {
      $(this).attr('target', '_blank');
    }
    if(!email.test(this.href) && !a.test(this.href)) {
      $(this).attr('rel', 'external');
    }
  });
  t.setupEvents();
};
return t;
})();

//Risk factors message
var risk_factors = (function() {
var t = {};
t.appriseWindow = function() {
	
	var opts = {'confirm': true, 'showFooter': true};
	
	if(t.current=='cnl-investor-ekit'){
		opts = {'confirm': true, 'showFooter': true, 'txtOK':'Continue'};
	}
	
  $(window).apprise(t.message(), opts, function(r) {
    if(r === true) {
      //Let them go
              if(t.current=='CNL Strategic Capital'){
                  $.cookie('killInternalPopup', 'TRUE', {path: '/', expires: 30});
              }else{
                  $.cookie(t.current, 'TRUE', {path: '/', expires: 30});
              }
    } else {
      //Send them packin
      window.history.go(-1);
    }
  });
};
t.message = function() {
  var message = [];


if(t.current == "Privacy Policy"){

message.push('<p style="max-width: 400px">Users who are not resident to the United States should not submit their personal information to our web-site or by submitting documents containing such information; they must affirm that they are not a resident of the European Union and agree that their personal information will be treated in accordance with United States laws and the terms of this Privacy Policy.</p>');
      
  }else if(t.brochurePop){
      //message.push('<p style="max-width: 400px">Not for use in Ohio.</p>');
      message.push('<p style="max-width: 400px">This piece is not for use in NJ.</p>');
      message.push('<p style="max-width: 400px">I verify that I am not a NJ resident.</p>');
	  
  }else if(t.current == "cnl-investor-ekit"){
      //message.push('<p style="max-width: 400px">Not for use in Ohio.</p>');
      message.push('<p style="max-width: 400px"><strong>CNL STRATEGIC CAPITAL</strong><br>Important Notice</p>');
      message.push('<p style="max-width: 400px">This site and the materials herein are directed only to certain types of investors and to persons in jurisdictions where CNL Strategic Capital is authorized for distribution.</p>');
      message.push('<p style="max-width: 400px">Complete information about investing in shares of CNL Strategic Capital is available in the <a href="https://www.cnlstrategiccapital.com/prospectus">prospectus</a>, which should be read carefully to fully understand all of the implications and risks associated with the offering.</p>');
      message.push('<p style="max-width: 400px"><a href="https://www.cnlstrategiccapital.com/prospectus">DOWNLOAD PROSPECTUS</a>');
      message.push('<p style="max-width: 400px">By selecting continue, you acknowledge that you have received the CNL Strategic Capital prospectus and that you are a United States resident.</p>');
  }else{
      
      
  if(t.nonAP === true) {
    message.push('<p style="max-width: 400px">If you are an Ameriprise Financial Services, Inc. Advisor please DO NOT utilize this form. A separate subscription agreement has been created for Amerprise use only.</p>');
  }
  if(t.AP === true) {
    message.push('<p style="max-width: 400px">This Subscription Agreement is for Ameriprise Financial Services, Inc. use only.</p>');
  }
  
  if(SPEC === 'large') {
    //message = [
      message.push('<p style="max-width: 400px">');
        message.push('Our website uses cookies to help us better understand how our site is used and to tailor advertising. By clicking OK and continuing to use this website, you are consenting to the use of cookies. ');
        message.push('<a href="/privacy-policies.stml">View privacy policy</a>');
      message.push('</p>');
      message.push('<p style="max-width: 400px">');
        message.push('There are significant risks and investment costs associated with an investment in CNL Strategic Capital. This investment is considered speculative and is not suitable for all investors. To view a summary of these risks and costs, see the Risk Factors below. This material must be read in conjunction with the prospectus to fully understand the implications and risks involved in this offering. ');
        message.push('Carefully read the <a href="/prospectus" target="_blank" aria-label="Investment Prospectus">prospectus</a> before investing.');
      message.push('</p>');
      message.push('<div class="apprise_docs">');
        message.push('<div class="col">');
          message.push('<a href="/prospectus" target="_blank">');
            message.push('<img src="/resources/images/doc_thumbs/prospectus.jpg" alt="Image of Prospectus document"/>');
            message.push('<br />Prospectus [PDF] &raquo;');
          message.push('</a>');
        message.push('</div>');
        message.push('<div class="col">');
          message.push('<a href="/risk-factors.stml" target="_blank">');
            message.push('<img src="/resources/images/doc_thumbs/riskfactors.jpg" alt="Image of Risk Factors document"/>');
            message.push('<br />Risk Factors &raquo;');
          message.push('</a>');
        message.push('</div>');
      message.push('</div>');
    //];
  } else {
    //message = [
      message.push('<p style="max-width: 400px">');
        message.push('Our website uses cookies to help us better understand how our site is used and to tailor advertising. By clicking OK and continuing to use this website, you are consenting to the use of cookies. ');
        message.push('<a href="/privacy-policies.stml">View privacy policy</a>');
      message.push('</p>');
      message.push('<p style="max-width: 400px">');
        message.push('There are significant risks and investment costs associated with an investment in CNL Strategic Capital. This investment is considered speculative and is not suitable for all investors. To view a summary of these risks and costs, see the Risk Factors below. This material must be read in conjunction with the prospectus to fully understand the implications and risks involved in this offering. ');
        message.push('Carefully read the <a href="/prospectus" target="_blank" aria-label="Investment Prospectus">prospectus</a> before investing.');
      message.push('</p>');
      message.push('<p class="document"><a href="/risk-factors.stml" target="_blank">');
        message.push('<img src="/resources/images/doc_thumbs/riskfactors.jpg" alt="Image of Risk Factors document"/>');
        message.push('<br />Risk Factors &raquo;');
      message.push('</a></p>');
      message.push('<p class="document"><a href="/prospectus" target="_blank">');
        message.push('<img src="/resources/images/doc_thumbs/prospectus.jpg" alt="Image of Prospectus document"/>');
        message.push('<br />Prospectus and Latest Supplements [PDF] &raquo;');
      message.push('</a></p>');
    
    //];
  }
}
  return message.join('');
};
t.pages = function() {
              return {
                              'reit-global-income-trust_page': 'Global Income Trust',
                              'reit-cnl-healthcare-trust_page': 'CNL Energy Total Return Fund',
                              'bdc-corporate-capital-trust_page': 'Corporate Capital Trust',
                              'reit-customized-allocations_page': 'Global Growth Trust and Global Income Trust',
                              'chp-popup_page': 'CNL Strategic Capital',
'privacy-policy':'Privacy Policy',
'ekit-popup':'cnl-investor-ekit'
              };
};

t.preAppriseWindow = function(link) {
  $(window).apprise(t.message(), {'confirm': true, 'showFooter': true}, function(r) {
    if(r === true) {
      //Let them go
              if(t.current=='CNL Strategic Capital'){
                  $.cookie('killInternalPopup', 'TRUE', {path: '/', expires: 30});
              }else{
                  $.cookie(t.current, 'TRUE', {path: '/', expires: 30});
              }
var ie = (function(){
  var undef,
      v = 3,
      div = document.createElement('div'),
      all = div.getElementsByTagName('i');
  while (
      div.innerHTML = '<!--[if gt IE ' + (++v) + ']><i></i><![endif]-->',
      all[0]
  );
  return v > 4 ? v : undef;
});

      if(ie)
      {
        window.open(link.attr('href'));
        //window.location.href(link.attr('href'));
      }
      else
      {
        window.open(link.attr('href'));
      }
      
      
      //window.open(""+link.attr('href')+"");
    } else {
      //Send them packin
      //alert(link.attr('href'));
      return false;
    }
  });
};
t.init = function() {
      var sitewide_popup = 0;
      var id2 = $('body .overview_page');
      var id = $('body').attr('id');
  if (!id && $('#overview_page').length > 0 || !id2 && $('.overview_page').length > 0){
    sitewide_popup = 1;
    $('body').attr('id', 'chp-popup_page');
  }
  id = $('body').attr('id');
  t.current = t.pages()[id];
  if(t.current) {
    if((sitewide_popup == 1 && !$.cookie('killInternalPopup')) || (sitewide_popup == 0 && !$.cookie(t.current))) {
      t.appriseWindow();
    } else {
              if(t.current = 'CNL Strategic Capital'){
                  $.cookie('killInternalPopup', 'TRUE', {path: '/', expires: 30});
              }else{
                  $.cookie(t.current, 'TRUE', {path: '/', expires: 30});
              }
      // else if there is a cookie it resets the cookie
    }
  }
  
  $('a.warn').bind('click', function(e) {
    t.current = $(this).attr('data-product');
          t.brochurePop = false;
       
    if($(this).hasClass('overview-brochure')) {
      t.brochurePop = true;
    }
       
    if($(this).hasClass('ameriprise')) {
      t.AP = true;
    }
    if($(this).hasClass('nonameriprise')) {
      t.nonAP = true;
    }
          
    if($(this).hasClass('partner_profile')) {
      t.brochurePop = true;
    }
    
    e.preventDefault();
    t.preAppriseWindow($(this));
    t.nonAP = false;
    t.AP = false;
    
    /*if(!$.cookie('killInternalPopup')) {
      e.preventDefault();
      t.preAppriseWindow($(this));
      t.nonAP = false;
      t.AP = false;
    } else {
      // else if there is a cookie it resets the cookie
      $.cookie('killInternalPopup', 'TRUE', {path: '/', expires: 30});
    }*/
  });
};
return t;
})();

//Form validation
var form = (function() {
var t = {};
t.container = null;
t.checkEmail = function(value) {
  return (/^((([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+(\.([a-z]|\d|[!#\$%&'\*\+\-\/=\?\^_`{\|}~]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])+)*)|((\x22)((((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(([\x01-\x08\x0b\x0c\x0e-\x1f\x7f]|\x21|[\x23-\x5b]|[\x5d-\x7e]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(\\([\x01-\x09\x0b\x0c\x0d-\x7f]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))))*(((\x20|\x09)*(\x0d\x0a))?(\x20|\x09)+)?(\x22)))@((([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|\d|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.)+(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])|(([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])([a-z]|\d|-|\.|_|~|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])*([a-z]|[\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF])))\.?$/i).test(value);
};
t.setupEvents = function() {
  t.container.bind('submit', function(e) {
    e.preventDefault();
    var error = false;
    $('.input .error', t.container).remove();
    $('.required', t.container).each(function() {
      var that = $(this);
      if(that.val() === '' || (that.attr('type') === 'email' && t.checkEmail(that.val()) === false)) {
        error = true;
        that.parents('.input').append('<div class="error">This field is required.</div>');
      }
    });
    if(error === false) {
      t.container.unbind('submit');
      t.container.submit();
    }
  });
  
  $('.required').blur(function() {
    var that = $(this);
    if(that.attr('type') === 'email' && t.checkEmail(that.val()) === true) {
      that.parents('.input').children('.error').remove();
    } else if(that.attr('type') !== 'email' && that.val() !== '') {
      that.parents('.input').children('.error').remove();
    }
  });
};
t.init = function() {
  t.container = $('form.new_contact');
  if(t.container.length > 0) {
    t.setupEvents();
  }
};
return t;
})();

//Portfolio marquee
var portfolio = (function() {
var t = {};
t.links = null;
t.mobile = function() {
  t.links.click(function(e) {
    if(SPEC === 'small') {
      e.preventDefault();
      t.panel();
    }
  });
};
t.panel = function() {
  var title = $('#main_content h1').clone();
  var images = [];
  $('#marquee a').each(function() {
    images.push($(this).attr('href'));
  });
  $('body').append('<div id="panel" />');
  var panel = $('#panel');
  $('#container').addClass('fixed');
  var close = $('<a href="#" class="close" onclick="portfolio.remove(); return false;">Return to overview</a>');
  panel.append(close);
  panel.append(title);
  for(var i in images) {
    panel.append('<img src="'+images[i]+'" />');
  }
};
t.remove = function() {
  $('#container').removeClass('fixed');
  $('body #panel').remove();
};
t.init = function() {
  t.links = $('#marquee a[rel=project_images]');
  if(t.links.length > 0) {
    t.links.fancybox({
      titlePosition:	'inside',
      titleFormat:		function(title, currentArray, currentIndex) {
        return '<div id="tip7-title">'+
                (title && title.length ? '<b>' + title + '</b>' : '' )+
                'Image ' + (currentIndex + 1) + ' of ' + currentArray.length + '</div>';
      }
    });
    if(SPEC === 'small') {
      t.links.unbind('click.fb');
    }
    t.mobile();
  }
};
return t;
})();

var news = (function() {
var t = {};
t.container = null;
t.current = 0;
t.items = null;
t.nav = null;
t.setupEvents = function() {
  $('li', t.nav).click(function() {
    $(this).addClass('active').siblings('li').removeClass('active');
    var index = $(this).index();
    var ul = $(this).parents('ul').siblings('ul');
    $('li', ul).hide();
    $('li:eq('+index+')', ul).show();
    t.current = index;
  });
  if($.browser.webkit && $.browser.webkit === true) {
    t.container.swipe({
      swipeLeft: function() {
        var next = t.current + 1;
        if(next > (t.items.length-1)) {
          next = 0;
        }
        $('li:eq('+next+')', t.nav).trigger('click');
      },
      swipeRight: function() {
        var prev = t.current - 1;
        if(prev < 0) {
          prev = (t.items.length - 1);
        }
        $('li:eq('+prev+')', t.nav).trigger('click');
      }
    });
  }
};
t.setupViews = function() {
  $('ul', t.container).after('<ul class="nav" />');
  t.nav = $('ul.nav', t.container);
  for(var i = 1; i <= t.items.length; i++) {
    t.nav.append('<li>'+i+'</li>');
  }
  $('li:first-child', t.nav).addClass('active');
};
t.init = function() {
  t.container = $('.home .latest_news_col');
  if(t.container.length > 0) {
    t.items = $('ul li', t.container);
    t.setupViews();
    t.setupEvents();
  }
};
return t;
})();

//Track window size
setSpec = function() {
var previous = SPEC;
SPEC = $(document).width() > 745 ? 'large' : 'small';
PREVWIDTH = CURRWIDTH;
CURRWIDTH = $(document).width();
if(previous === 'small' && SPEC === 'large') {
  $('a[rel=lightbox], #marquee a[rel=project_images]').bind('click.fb');
  slider.realign();
} else if(previous === 'large' && SPEC === 'small') {
  $('a[rel=lightbox], #marquee a[rel=project_images]').unbind('click.fb');
  slider.realign();
}
return CURRWIDTH;
};

$(function() {
setSpec();
$(window).resize(function() {
  return setSpec();
});

slider.init();
links.init();
risk_factors.init();
form.init();
portfolio.init();
news.init();

if(jQuery.browser.msie && parseInt(jQuery.browser.version, 10) <= 8) {
  $('html').addClass('no-overflowscrolling');
} else {
  Modernizr.addTest('overflowscrolling', function() {
    Modernizr.testAllProps('overflowScrolling');
  });
}

//Globally Focused Accordion
//$('.accordion').hover(function() {
//	$('p', this).hide();
//}, function() {
//	$('p', this).show();
//});

//$('.accordion_item').hover(function() {
//	$('img', this).show();
//}, function() {
//	$('img', this).hide();
//});

//Investment Strategy Graph
if($('#investment_criteria').length > 0) {
  setTimeout(function() {
    $("#investment_criteria").animate({width:'100%'},2000);
  }, 1000);
}

$('a[rel=lightbox]').fancybox();
if(SPEC === 'small') {
  $('a[rel=lightbox]').unbind('click.fb');
}

if(!Modernizr.borderradius) {
  $('#main_nav a.top').append('<b class="l"></b><b class="r"></b>');
}

//Toggle mobile nav
$('.supplement .toggle a, .supplement a.return').click(function(e) {
  e.preventDefault();
  $('#container').toggleClass('open');
});

//Add openers for main nav
$('#main_nav li:has("ul") a.top, #main_nav li a.parent').append('<b />');
$('#main_nav a').live('click', function(e) {
  if(e.srcElement.nodeName === 'B') {
    e.preventDefault();
    var li = $(this).parent();
    li.toggleClass('current').siblings('li').removeClass('current');
    return false;
  } else {
    $('#container').removeClass('open');
    return true;
  }
});

//Move supplemental subnav content to main content for mobile
var sub_content = $('.sub_content .column_sub, .sub_content .building');
if(sub_content.length > 0) {
  var c = sub_content.clone();
  if($('#offering_highlights_page').length > 0) {
    c.insertAfter('#main_content table');
  } else {
    c.appendTo('#main_content .content_wrapper');
  }
}

//if ie6
if(jQuery.browser.msie && parseInt(jQuery.browser.version, 10) === 6) {
  //Fix columns for ie6
  var h = $('#main_content').height();
  $('.sub_content').height(h);
  
  //Support nav hover for ie6
  $('#main_nav li').hover(function() {
    $(this).children('ul').show();
  }, function() {
    $(this).children('ul').hide();
  });
}
});